@@ -5,7 +5,7 @@ import time
 import json
 import traceback
 from queue import Queue
-from rsudp import printM, printW, printE, default_loc, init_dirs, output_dir, add_debug_handler, start_logging
+from rsudp import printM, printW, printE, default_loc, init_dirs, settings_loc, add_debug_handler, start_logging
 from rsudp import COLOR
 import rsudp.helpers as H
 import rsudp.test as T
@@ -306,12 +306,14 @@ def run(settings, debug):
 		token = settings['telegram']['token']
 		chat_ids = settings['telegram']['chat_id'].strip(' ').split(',')
 		send_images = settings['telegram']['send_images']
+		extra_text = settings['telegram']['extra_text']
+
 		for chat_id in chat_ids:
 			sender = "Telegram id %s" % (chat_id)
 			q = mk_q()
 			TELEGRAM = Telegrammer(q=q, token=token, chat_id=chat_id,
-								   send_images=send_images, testing=TESTING,
-								   sender=sender)
+								   send_images=send_images, extra_text=extra_text,
+								   sender=sender, testing=TESTING)
 			mk_p(TELEGRAM)
 
 	if settings['rsam']['enabled']:
@@ -367,7 +369,6 @@ def main():
 	Loads settings to start the main client.
 	Supply -h from the command line to see help text.
 	'''
-	settings_loc = os.path.join(default_loc, 'rsudp_settings.json').replace('\\', '/')
 
 	hlp_txt='''
 ###########################################
@@ -508,7 +509,7 @@ default settings and the data file at
 	settings_are_default = True
 	plot = True
 	quiet = False
-	packetize(inf=TESTFILE+'.ms', outf=TESTFILE, testing=True)
+	customfile = False
 
 	try:
 		opts = getopt.getopt(sys.argv[1:], 'hf:s:bq',
@@ -532,8 +533,9 @@ default settings and the data file at
 			if os.path.exists(a):
 				try:
 					out = '%s.txt' % (a)
-					packetize(inf=a, outf=out)
+					packetize(inf=a, outf=out, testing=True)
 					TESTFILE = out
+					customfile = True # using a custom miniseed file for testing
 				except Exception as e:
 					print(hlp_txt)
 					print(COLOR['red'] + 'ERROR: %s' % e + COLOR['white'])
@@ -554,6 +556,9 @@ default settings and the data file at
 		if o in ('-q', '--no-sound'):
 			quiet = True
 
+	if not customfile:
+		# we are just using the default miniseed file
+		packetize(inf=TESTFILE+'.ms', outf=TESTFILE, testing=True)
 
 	T.TEST['n_internet'][1] = T.is_connected('www.google.com')
 
@@ -575,7 +580,7 @@ default settings and the data file at
 
 		# client test
 		ctest = 'client test'
-		if T.TEST['c_miniseed']:
+		if (T.TEST['c_miniseed'] and WRITER):
 			printM('Merging and testing MiniSEED file(s)...', sender=ctest)
 			try:
 				ms = rs.Stream()
@@ -588,7 +593,7 @@ default settings and the data file at
 					else:
 						raise FileNotFoundError('MiniSEED file not found: %s' % outfile)
 				printM('Renamed test file(s).', sender=ctest)
-				printM(ms.merge())
+				printM(ms.merge().__str__())
 			except Exception as e:
 				printE(e)
 				T.TEST['c_miniseed'][1] = False
