@@ -1,8 +1,5 @@
-from datetime import datetime, timedelta
-import time
-import math
 import numpy as np
-import sys, os, platform
+import os, platform
 import socket as s
 import signal
 from obspy import UTCDateTime
@@ -13,6 +10,7 @@ from obspy.core.trace import Trace
 from rsudp import printM, printW, printE
 from requests.exceptions import HTTPError
 from threading import Thread
+from . import __version__
 
 initd, sockopen = False, False
 qsize = 2048 			# max queue size
@@ -133,8 +131,8 @@ def initRSlib(dport=port, rsstn='Z0000', timeout=10):
 	'''
 	global port, stn, to, initd, port
 	global producer
-	sender = 'Init'
-	printM('Initializing.', sender)
+	sender = 'RS lib'
+	printM('Initializing rsudp v %s.' % (__version__), sender)
 	try:						# set port value first
 		if dport == int(dport):
 			port = int(dport)
